Download source file from database
download_from_database(
source_root,
source_path,
path,
filename,
overwrite = FALSE
)a string specifying the source root
a string specifying the source path
a string specifying where the file will be saved
a string specifying the filename (the name given to
the saved file)
a boolean specifying whether or not the file should
be overwritten if it already exists
Other download functions:
download_from_url()