Learn R Programming

rDataPipeline (version 0.60.0)

download_from_url: Download source file from URL

Description

This function will download a file from a url

Usage

download_from_url(source_root, source_path, path, filename)

Arguments

source_root

a string specifying the source root

source_path

a string specifying the source path

path

a string specifying where the file will be saved

filename

a string specifying the filename (the name given to the saved file)

See Also

Other download functions: download_from_database()