Learn R Programming

rDataPipeline (version 0.60.0)

findme: findme

Description

Returns metadata associated with the calculated hash of a target file. When multiple entries exist in the data registry all are returned.

Usage

findme(file, endpoint)

Arguments

file

file path

endpoint

endpoint