Upload information to the author table in the data registry
new_author(name, identifier, endpoint = "http://127.0.0.1:8000/api/")a string specifying the full name or organisation name of
the author; note that at least one of name or identifier must be
specified
(optional) a string specifying the full URL
identifier (e.g. ORCiD or ROR ID) of the author
a string specifying the registry endpoint
Other new functions:
new_code_repo_release(),
new_code_run(),
new_data_product(),
new_external_object(),
new_file_type(),
new_issue(),
new_keyword(),
new_licence(),
new_namespace(),
new_object(),
new_object_component(),
new_quality_controlled(),
new_storage_location(),
new_storage_root(),
new_user_author()